@@ -76,10 +76,13 @@ pub struct Initial {
     system_name: String,
     id: String,
     command: String,
+    #[serde(default)]
+    prepare_command: Option<String>,
     data_path: String,
     timeout: Timeout,
     core: CoreInfo,
     bus: BusConfig,
+    #[serde(default)]
     config: Option<Value>,
     #[serde(default = "default_workers")]
     workers: u32,
@@ -91,6 +94,7 @@ impl Initial {
         id: &str,
         system_name: &str,
         command: &str,
+        prepare_command: Option<&str>,
         data_path: &str,
         timeout: &Timeout,
         core_info: CoreInfo,
@@ -103,6 +107,7 @@ impl Initial {
             system_name: system_name.to_owned(),
             id: id.to_owned(),
             command: command.to_owned(),
+            prepare_command: prepare_command.map(ToOwned::to_owned),
             data_path: data_path.to_owned(),
             timeout: timeout.clone(),
             core: core_info,
@@ -128,6 +133,10 @@ impl Initial {
         &self.command
     }
     #[inline]
+    pub fn prepare_command(&self) -> Option<&str> {
+        self.prepare_command.as_deref()
+    }
+    #[inline]
     pub fn data_path(&self) -> &str {
         &self.data_path
     }
