@@ -1,6 +1,5 @@
 //use eva_common::prelude::*;
 use crate::Error;
-use log::{debug, error};
 use serde::{Deserialize, Deserializer, Serializer};
 use std::str::FromStr;
 use std::sync::atomic;
@@ -63,29 +62,52 @@ pub fn format_path(base: &str, path: Option<&str>, default: Option<&str>) -> Str
     }
 }
 
-pub trait ErrLogger {
-    fn log_err(self) -> Self;
-    fn log_err_as_debug(self) -> Self;
-}
+#[macro_export]
+macro_rules! err_logger {
+    () => {
+        pub trait ErrLogger {
+            /// log error and forget the result
+            fn log_ef(self);
+            /// log error as debug and forget the result
+            fn log_efd(self);
+            /// log error and keep the result
+            fn log_err(self) -> Self;
+            /// log error as debug and keep the result
+            fn log_ed(self) -> Self;
+        }
 
-impl<R, E> ErrLogger for Result<R, E>
-where
-    E: std::fmt::Display,
-{
-    #[inline]
-    fn log_err(self) -> Self {
-        if let Err(ref e) = self {
-            error!("{}", e);
+        impl<R, E> ErrLogger for Result<R, E>
+        where
+            E: std::fmt::Display,
+        {
+            #[inline]
+            fn log_ef(self) {
+                if let Err(ref e) = self {
+                    log::error!("{}", e);
+                }
+            }
+            #[inline]
+            fn log_efd(self) {
+                if let Err(ref e) = self {
+                    log::debug!("{}", e);
+                }
+            }
+            #[inline]
+            fn log_err(self) -> Self {
+                if let Err(ref e) = self {
+                    log::error!("{}", e);
+                }
+                self
+            }
+            #[inline]
+            fn log_ed(self) -> Self {
+                if let Err(ref e) = self {
+                    log::debug!("{}", e);
+                }
+                self
+            }
         }
-        self
-    }
-    #[inline]
-    fn log_err_as_debug(self) -> Self {
-        if let Err(ref e) = self {
-            debug!("{}", e);
-        }
-        self
-    }
+    };
 }
 
 // atomic functions (not implemented in serde for certain archs)
